@@ -8,7 +8,7 @@ use Cwd;
 use File::Temp;
 use List::Util qw(first sum);
 
-our $VERSION = '0.19';
+our $VERSION = '0.20';
 $VERSION = eval $VERSION;
 
 =head1 NAME
@@ -67,11 +67,42 @@ This package inherits methods from F<Devel::Git::MultiBisect>.  Only methods uni
 F<Devel::Git::MultiBisect::AllCommits> are documented here.  See the documentation for
 F<Devel::Git::MultiBisect> for all other methods, including:
 
-    new()
     get_commits_range()
     set_targets()
     run_test_files_on_one_commit()
 
+=head2 C<new()>
+
+=over 4
+
+=item * Purpose
+
+Constructor.
+
+=item * Arguments
+
+    $self = Devel::Git::MultiBisect::AllCommits->new(\%params);
+
+Reference to a hash, typically the return value of
+C<Devel::Git::MultiBisect::Opts::process_options()>.
+
+=item * Return Value
+
+Object of Devel::Git::MultiBisect child class.
+
+=back
+
+=cut
+
+sub new {
+    my ($class, $params) = @_;
+    my $data = $class->SUPER::new($params);
+
+    delete $data->{probe};
+
+    return bless $data, $class;
+}
+
 =head2 C<run_test_files_on_all_commits()>
 
 =over 4
