@@ -10,7 +10,7 @@ use Carp;
 use File::Spec;
 use File::Temp qw( tempdir );
 
-our $VERSION = '0.19';
+our $VERSION = '0.20';
 $VERSION = eval $VERSION;
 
 =head1 NAME
@@ -25,7 +25,7 @@ Devel::Git::MultiBisect::BuildTransitions - Gather build-time output where it ch
 
     $commit_range = $self->get_commits_range();
 
-    $self->multisect_builds( { probe => 'error' } );
+    $self->multisect_builds();
 
     $multisected_outputs = $self->get_multisected_outputs();
 
@@ -41,20 +41,20 @@ cases:
 
 =over 4
 
-=item * Build-time failures
+=item * Build-time failures: C<probe =E<gt> 'error'>
 
 While running your C-compiler over C source code via F<make>, an exception may
 be thrown which causes the build to fail.  Over a large number of commits,
 different exceptions may be thrown at various commits.  Identify those
 commits.
 
-=item * Build-time C-level warnings
+=item * Build-time C-level warnings: C<probe =E<gt> 'warning'>
 
 Your C-compiler may identify sub-optimal C source code and emit warnings.
 Over a large number of commits, different warnings may be thrown at various
 commits.  Identify the commits where the warnings changed.
 
-=item * Build-time non-C-level warnings
+=item * Build-time non-C-level warnings: C<probe =E<gt> 'stderr'>
 
 At build time F<make> is not limited to running a C compiler; it may also
 execute statements in Perl, shell or other languages.  Those statements may
@@ -63,8 +63,10 @@ from F<make> changes.
 
 =back
 
-These three cases are distinguished by the arguments passed to the
-C<multisect_builds()> method described below.
+These three cases are distinguished by the C<probe> key-value pair passed to
+C<new()>, the constructor, or to the C<multisect_builds()> method described
+below.  The default value for C<probe> is C<'error'>, I<i.e.,> to multisect
+for build-time exceptions.
 
 =head1 METHODS
 
@@ -81,7 +83,20 @@ Constructor.
     $self = Devel::Git::MultiBisect::BuildTransitions->new(\%params);
 
 Reference to a hash, typically the return value of
-C<Devel::Git::MultiBisect::Opts::process_options()>.
+C<Devel::Git::MultiBisect::Opts::process_options()>.  Example:
+
+    %args = (
+        gitdir              => "~/gitwork/perl",
+        outputdir           => tempdir(),
+        first               => 'd4bf6b07402c770d61a5f8692f24fe944655d99f',
+        last                => '9be343bf32d0921e5c792cbaa2b0038f43c6e463',
+        branch              => 'blead',
+        configure_command   => 'sh ./Configure -des -Dusedevel',
+        verbose             => 1,
+        probe               => 'stderr,
+    );
+    $params = Devel::Git::MultiBisect::opts::process_options(%args);
+    $self = Devel::Git::MultiBisect::BuildTransitions->new($params);
 
 =item * Return Value
 
@@ -113,28 +128,31 @@ commits, identify the points where the output of the "build command" --
 typically, F<make> -- materially changed.
 
 A B<material change> would be either (a) the emergence or correction of
-C-level exceptions; (b) the emergence or correction of C-level warnings; (c)
-the emergence or correction of F<STDERR> output emitted during F<make> by
-Perl, shell or other non-C code.
+C-level exceptions (C<error>); (b) the emergence or correction of C-level
+warnings (C<warning>); (c) the emergence or correction of F<STDERR> output
+emitted during F<make> by Perl, shell or other non-C code (C<stderr>).
 
-These three cases are distinguished by the arguments passed to this method.
+=item * B<NOTICE OF CHANGE OF INTERFACE>
+
+Up through version 0.19 of F<Devel::Git::MultiBisect::BuildTransitions>, the
+recommended (indeed, only) way to select among C<error>, C<warning> and
+C<stderr> was to pass your choice as the value of a hash reference keyed on
+C<probe> to the C<multisect_builds()> method.  As of version 0.20, the
+recommended way is to provide the C<probe =E<gt> 'value'> key-value pair as
+one of the elements passed to C<new()>, the constructor (typically via
+C<Devel::Git::MultiBisect::opts::process_options(%params)>).  Beginning in
+January 2022, C<multisect_builds()> will no longer do anything with arguments
+passed to it.
 
 =item * Arguments
 
-    $self->multisect_builds();      # defaults to { probe => 'error' }
+    $self->multisect_builds();
 
-    $self->multisect_builds({ probe => 'error' });
+    $self->multisect_builds({ probe => 'error' });      # DEPRECATED
 
-    $self->multisect_builds({ probe => 'warning' });
+    $self->multisect_builds({ probe => 'warning' });    # DEPRECATED
 
-    $self->multisect_builds({ probe => 'stderr' });
-
-Optionally takes one hash reference.  At present that hashref may contain only
-one element whose key is C<probe> and whose possible values are C<error>,
-C<warning>, or C<stderr>.  Defaults to C<error>.  Select among these values
-depending on whether you are probing for changes in errors generated by the
-C-compiler, changes in warnings generated by the C-compiler, or all text
-output to C<STDERR> during F<make>.
+    $self->multisect_builds({ probe => 'stderr' });     # DEPRECATED
 
 =item * Return Value
 
@@ -153,12 +171,21 @@ through method calls.
 
 =item *
 
-It captures error messages from each commit run and writes them to a file on
-disk for later human inspection.  (If you have selected C<probe =E<gt> 'stderr'>,
-all content directed to F<STDERR> is written to that file.)
+Depending on the value assigned to C<probe>, the method captures build-time
+error messages (C<error>) or warnings (C<warning>) from each commit run and
+writes them to a file on disk for later human inspection.  If you have
+selected C<probe =E<gt> 'stderr'>, all content directed to F<STDERR> is
+written to that file.
 
 =back
 
+=item *
+
+If you are using F<Devel::Git::Multisect::BuildTransitions> to diagnose
+problems in the Perl 5 core distribution, C<multisect_builds()> will take some
+time to run, as F<perl> will have to be configured and built for each commit
+run.
+
 =back
 
 =cut
@@ -167,6 +194,7 @@ sub multisect_builds {
     my ($self, $args) = @_;
 
     # Methods called within multisect_builds:
+    # _validate_multisect_builds_args
     # _prepare_for_multisection
     #       get_commits_range
     #       run_build_on_one_commit
@@ -177,22 +205,7 @@ sub multisect_builds {
     # _bisection_decision
     # _evaluate_status_of_build_runs
 
-    if (defined $args) {
-        croak "Argument passed to multisect_builds() must be hashref"
-            unless ref($args) eq 'HASH';
-        my %good_keys = map {$_ => 1} (qw| probe |);
-        for my $k (keys %{$args}) {
-            croak "Invalid key '$k' in hashref passed to multisect_builds()"
-                unless $good_keys{$k};
-        }
-        my %good_values = map {$_ => 1} (qw| error warning stderr |);
-        for my $v (values %{$args}) {
-            croak "Invalid value '$v' in 'probe' element in hashref passed to multisect_builds()"
-                unless $good_values{$v};
-        }
-    }
-    $args->{probe} = 'error' unless defined $args->{probe};
-    $self->{probe} = $args->{probe};
+    my $probe_validated = $self->_validate_multisect_builds_args($args);
 
     # Prepare data structures in the object to hold results of build runs on a
     # per target, per commit basis.
@@ -311,6 +324,31 @@ sub multisect_builds {
     return 1;
 }
 
+sub _validate_multisect_builds_args {
+    my ($self, $args) = @_;
+    if (defined $args) {
+        croak "Argument passed to multisect_builds() must be hashref"
+            unless ref($args) eq 'HASH';
+        my %good_keys = map {$_ => 1} (qw| probe |);
+        for my $k (keys %{$args}) {
+            croak "Invalid key '$k' in hashref passed to multisect_builds()"
+                unless $good_keys{$k};
+        }
+        my %good_values = map {$_ => 1} (qw| error warning stderr |);
+        for my $v (values %{$args}) {
+            croak "Invalid value '$v' in 'probe' element in hashref passed to multisect_builds()"
+                unless $good_values{$v};
+        }
+        $self->{probe} = $args->{probe};
+    }
+    else {
+        # If no $args passed to multisect_build(), then we rely on either
+        # the value for 'probe' provided by user to new() or the default value
+        # -- 'error' -- now provided in Devel::Git::MultiBisect::Opts.
+    }
+    return $self->{probe};
+}
+
 sub _prepare_for_multisection {
     my $self = shift;
 
