@@ -11,7 +11,7 @@ use Cwd;
 use File::Temp;
 use List::Util qw(sum);
 
-our $VERSION = '0.19';
+our $VERSION = '0.20';
 $VERSION = eval $VERSION;
 
 =head1 NAME
@@ -69,10 +69,41 @@ This package inherits methods from F<Devel::Git::MultiBisect>.  Only methods uni
 F<Devel::Git::MultiBisect::Transitions> are documented here.  See the documentation for
 F<Devel::Git::MultiBisect> for all other methods, including:
 
-    new()
     get_commits_range()
     set_targets()
 
+=head2 C<new()>
+
+=over 4
+
+=item * Purpose
+
+Constructor.
+
+=item * Arguments
+
+    $self = Devel::Git::MultiBisect::Transitions->new(\%params);
+
+Reference to a hash, typically the return value of
+C<Devel::Git::MultiBisect::Opts::process_options()>.
+
+=item * Return Value
+
+Object of Devel::Git::MultiBisect child class.
+
+=back
+
+=cut
+
+sub new {
+    my ($class, $params) = @_;
+    my $data = $class->SUPER::new($params);
+
+    delete $data->{probe};
+
+    return bless $data, $class;
+}
+
 =head2 C<multisect_all_targets()>
 
 =over 4
